@@ -5,16 +5,19 @@ cd "$(dirname "$0")"
 npm ci
 npm run check
 
-(cd ../wasm && wasm-pack build --target no-modules --out-dir ../web/pkg)
+rm -rf ../wasm/pkg-fend-web
+(cd ../wasm && wasm-pack build --target web --out-dir pkg-fend-web)
 
-convert -resize "128x128" ../icon/icon.svg fend-icon-128.png
+convert -resize "128x128" ../icon/icon.svg public/fend-icon-128.png
 
-mkdir -p documentation
+mkdir -p public/documentation
 
 (cd ../documentation && pandoc --standalone \
-	--output=../web/documentation/index.html \
+	--output=../web/public/documentation/index.html \
 	--metadata-file=pandoc-metadata.yml \
 	--lua-filter=include-code-files.lua \
 	--lua-filter=include-files.lua \
 	--lua-filter=add-header-ids.lua \
 	index.md)
+
+npm run build
